@@ -24,6 +24,8 @@ GOOD_LICENSES = set([
     # ...
 ])
 
+UNKNOWN_STR = "UNKNOWN"
+
 
 def format_license(license, ok=True):
     # Avoid sending garbage to the output when being piped.
@@ -49,14 +51,35 @@ def display(name, version, license, stream=None):
     stream.write('\n')
 
 
+def find_classifier(classifiers):
+    for row in classifiers:
+        if row.startswith("License"):
+            return row
+
+
+def extract_license(pkg_info):
+    # 1st try: raw `license` field.
+    license = pkg_info.get("license", UNKNOWN_STR).strip()
+    if license != UNKNOWN_STR:
+        return license
+
+    # 2nd try: parsing classifiers.
+    matched = find_classifier(pkg_info.get("classifiers", []))
+    if matched:
+        return matched.split("::")[-1].strip()
+
+    return UNKNOWN_STR
+
+
 def display_dist(dist):
     name, version = dist.project_name, dist.version
 
     info = api.release_data(name, version)
-    license = info.get("license", "UNKNOWN").strip()
+    license = extract_license(info)
 
     display(name, version, license)
 
+
 def main():
     for dist in get_installed_distributions():
         display_dist(dist)
